'use strict';

/**
 * Wraps all embeds in responsive aspect-ratio-aware containers.
 */
(function () {
  // List of supported services.
  var supports = ['youtube.com', 'vimeo.com', 'kickstarter.com'];

  // Get all embeds.
  var embeds = document.querySelectorAll(supports.map(function (service) {
    return 'iframe[src*="' + service + '"]';
  }).join());

  // Quick return if no embeds found.
  if (!embeds.length) return;

  // Iterate through all embeds and do the magic.
  for (var i = 0; i < embeds.length; i += 1) {
    // Get embed.
    var embed = embeds[i];

    // Remove wrapping paragraph tag.
    if (embed.parentNode.tagName === 'P') {
      var p = embed.parentNode;
      var entryContent = p.parentNode;
      entryContent.insertBefore(embed, p);
      entryContent.removeChild(p);
    }

    // Calculate padding.
    var padding = embed.getAttribute('height') * 100 / embed.getAttribute('width');

    // Create Outer Wrapping Element.
    var wrapperOuter = document.createElement('div');
    wrapperOuter.setAttribute('class', 'responsive-embed');

    // Create Inner Wrapping Element.
    var wrapperInner = document.createElement('div');
    wrapperInner.setAttribute('class', 'responsive-embed__inner');
    wrapperInner.setAttribute('style', 'padding-bottom:' + padding + '%;');

    // Add wrapper on the page before the embed.
    embed.parentNode.insertBefore(wrapperOuter, embed);

    // Move embed to the wrapper.
    wrapperInner.appendChild(embed);
    wrapperOuter.appendChild(wrapperInner);

    // Remove width and height attributes.
    embed.removeAttribute('width');
    embed.removeAttribute('height');
  }
})();